@extends('layouts.simple')

@section('title', 'UoS Student Login')

@section('css')
    <link href="https://login.uos.ac.uk/module.php/ucs/assets/css/style.css" rel="stylesheet" type="text/css"/>
    <style>
        a {
            color: #333333 !important;
            text-decoration: none;
        }
    </style>
    @if(env('APP_JS_DEV_MODE'))
        <link href="/css/sso.css" rel="stylesheet" type="text/css"/>
    @else
        <link href="/dist/css/sso.min.css" rel="stylesheet" type="text/css"/>
    @endif
@endsection


@section('javascript')
    <script src="/jspm_packages/system.js"></script>
    <script src="/jspm.config.js"></script>

    @if(env('APP_JS_DEV_MODE'))
        <script type="text/javascript">
            System.import('/authstack/pages/sso/index.js');
        </script>
    @else
        <script src="/dist/js/sso.min.js" type="text/javascript"></script>
    @endif

    <script>
        function goBack() {
            window.history.back();
        }
    </script>
@endsection


@section('content')
    <div id="SSO">
        <div class="main-wrap">
            <div class="login-left">
                <div class="logo-box">
                    <a href="https://www.ucs.ac.uk/home.aspx" target="_blank">
                        <img src="https://login.uos.ac.uk/module.php/ucs/assets/img/UCS-logo.png"
                             alt="Irish Management Institute">
                    </a>
                </div>
                <div class="left-bottom">
                    <a href="http://www.facebook.com/UniofSuffolk" target="_blank"><img
                                src="https://login.uos.ac.uk/module.php/ucs/assets/img/icon-facebook.svg"
                                alt="Irish Management Institute"></a>
                    <a href="http://twitter.com/UniofSuffolk" target="_blank"><img
                                src="https://login.uos.ac.uk/module.php/ucs/assets/img/icon-twitter.svg"
                                alt="Irish Management Institute"></a>
                    <a href="http://www.youtube.com/user/UCSLife" target="_blank"><img
                                src="https://login.uos.ac.uk/module.php/ucs/assets/img/icon-youtube.svg"
                                alt="University of Suffolk"></a>
                </div>
                <div class="clearfix"></div>
            </div>
            <div class="login-right">

                <a href="https://www.ucs.ac.uk/home.aspx" target="_blank" class="home-icon"><img
                            src="https://login.uos.ac.uk/module.php/ucs/assets/img/icon-home.svg"
                            alt="University of Suffolk"></a>

                <div class="mobile-box">
                    <img src="https://login.uos.ac.uk/module.php/ucs/assets/img/UCS-logo.png"
                         alt="Irish Management Institute">
                </div>

                <h2 class="login-title">{{ $title }}</h2>

                <div id="authentication" style="display:none">

                    <h4>{{ $message }}</h4>

                    <div class="form-group row mb-0">
                        <div class="col-md-6 offset-md-4">
                            <button onclick="goBack()" id="regularsubmit" class="ucs-btn">Go back</button>
                        </div>
                    </div>

                </div>

                <div class="right-bottom">
                    <span class="bot-left-text"> Switchboard: <a href="tel:+441473338000">+44 (0)1473 338000</a></span>
                    <span class="bot-right-text">Course Enquiries: <a
                                href="tel:+441473338833">+44 (0)1473 338833</a></span>
                    <div class="as-link-container"><a
                                href="https://its.uos.ac.uk/content/authstack-accessibility-statement" target="_blank">
                            Accessibility Statement
                        </a></div>
                    <span class="mobile-show">
				<a href="http://www.facebook.com/UniofSuffolk" target="_blank"><img
                            src="https://login.uos.ac.uk/module.php/ucs/assets/img/icon-facebook.svg"
                            alt="Irish Management Institute"></a>
				<a href="http://twitter.com/UniofSuffolk" target="_blank"><img
                            src="https://login.uos.ac.uk/module.php/ucs/assets/img/icon-twitter.svg"
                            alt="Irish Management Institute"></a>
				<a href="http://www.youtube.com/user/UCSLife" target="_blank"><img
                            src="https://login.uos.ac.uk/module.php/ucs/assets/img/icon-youtube.svg"
                            alt="Irish Management Institute"></a>
			</span>
                </div>
            </div>
            <div class="clearfix"></div>
        </div>
    </div>
@endsection
